// src/toggle.connect.ts
import { dataAttr } from "@zag-js/dom-query";

// src/toggle.dom.ts
import { createScope } from "@zag-js/dom-query";
var dom = createScope({
  getButtonId: (ctx) => ctx.ids?.button ?? `toggle:${ctx.id}:button`
});

// src/toggle.anatomy.ts
import { createAnatomy } from "@zag-js/anatomy";
var anatomy = createAnatomy("toggle").parts("button");
var parts = anatomy.build();

// src/toggle.connect.ts
function connect(state, send, normalize) {
  const isPressed = state.context.pressed;
  const isDisabled = state.context.disabled;
  return {
    isPressed,
    setPressed(pressed) {
      send({ type: "PRESSED.SET", pressed });
    },
    buttonProps: normalize.button({
      ...parts.button.attrs,
      id: dom.getButtonId(state.context),
      type: "button",
      disabled: isDisabled,
      "aria-label": state.context["aria-label"],
      "aria-pressed": isPressed,
      "data-disabled": dataAttr(isDisabled),
      "data-state": isPressed ? "on" : "off",
      onClick() {
        if (isDisabled)
          return;
        send({ type: "PRESSED.TOGGLE" });
      }
    })
  };
}

// src/toggle.machine.ts
import { createMachine } from "@zag-js/core";
import { compact } from "@zag-js/utils";
function machine(userContext) {
  const ctx = compact(userContext);
  return createMachine(
    {
      id: "toggle",
      initial: "ready",
      context: {
        "aria-label": "Toggle",
        disabled: false,
        pressed: false,
        ...ctx
      },
      watch: {
        pressed: ["invokeOnChange"]
      },
      on: {
        "PRESSED.SET": {
          actions: ["setPressed"]
        },
        "PRESSED.TOGGLE": {
          actions: ["togglePressed"]
        }
      },
      states: {
        ready: {}
      }
    },
    {
      actions: {
        invokeOnChange(ctx2) {
          ctx2.onChange?.({ pressed: !!ctx2.pressed });
        },
        togglePressed(ctx2) {
          ctx2.pressed = !ctx2.pressed;
        },
        setPressed(ctx2, evt) {
          ctx2.pressed = evt.pressed;
        }
      }
    }
  );
}
export {
  connect,
  machine
};
//# sourceMappingURL=index.mjs.map